@@ -11,13 +11,13 @@ from proxylist import now
 
 def check_proxies():
     mirrors = Mirror.objects.all()
-    proxies = Proxy.objects.filter(next_check__lte=now())
+    proxies = Proxy.objects.filter(next_check__lte=now()).order_by('errors')
 
     for p in proxies:
         m = choice(mirrors)
         if not m.is_checking(p):
             try:
-                m.check(p)
+                m.check_proxy(p)
             except Exception, msg:
                 if settings.DEBUG:
                     print('%s - %s' % (str(p), msg))
