@@ -2,25 +2,17 @@
 
 import json
 
+from django.views.decorators.cache import never_cache
 from django.http import HttpResponse
 
 from proxylist import now
 
 
+@never_cache
 def mirror(request):
-    """
-    from dateutil.parser import parse
-    from dateutil.tz import tzoffset
-    from datetime import datetime
-
-    parse("2012-12-28 22:22:12.868342+04:00")
-    datetime(2012, 12, 28, 22, 22, 12, 868342,
-             tzinfo=tzoffset(None, 14400))
-    """
-
     start = now()
 
-    SERIALIZABLE = (str, unicode, bool, int, float)
+    serializable = (str, unicode, bool, int, float)
 
     output = dict()
 
@@ -30,7 +22,7 @@ def mirror(request):
     # HTTP Headers
     output['http_headers'] = dict()
     for k, v in request.META.items():
-        if k.startswith('HTTP_') and type(v) in SERIALIZABLE:
+        if k.startswith('HTTP_') and type(v) in serializable:
             output['http_headers'][k[5:]] = v
 
     # Timing
